@@ -23,17 +23,15 @@
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
 define(['jquery', 'core/modal_events', 'core/modal_registry', 'core/modal',
-        'core/modal_save_cancel', 'core/modal_confirm', 'core/modal_cancel',
+        'core/modal_save_cancel', 'core/modal_cancel',
         'core/templates', 'core/notification', 'core/custom_interaction_events'],
-    function($, ModalEvents, ModalRegistry, Modal, ModalSaveCancel, ModalConfirm,
+    function($, ModalEvents, ModalRegistry, Modal, ModalSaveCancel,
         ModalCancel, Templates, Notification, CustomEvents) {
 
     // The templates for each type of modal.
     var TEMPLATES = {
         DEFAULT: 'core/modal',
         SAVE_CANCEL: 'core/modal_save_cancel',
-        // Deprecated since Moodle 3.4. Point template to core/modal_save_cancel instead. See MDL-59759.
-        CONFIRM: 'core/modal_save_cancel',
         CANCEL: 'core/modal_cancel',
     };
 
@@ -41,16 +39,12 @@ define(['jquery', 'core/modal_events', 'core/modal_registry', 'core/modal',
     var TYPES = {
         DEFAULT: 'DEFAULT',
         SAVE_CANCEL: 'SAVE_CANCEL',
-        // Deprecated since Moodle 3.4. See MDL-59759.
-        CONFIRM: 'CONFIRM',
         CANCEL: 'CANCEL',
     };
 
     // Register the common set of modals.
     ModalRegistry.register(TYPES.DEFAULT, Modal, TEMPLATES.DEFAULT);
     ModalRegistry.register(TYPES.SAVE_CANCEL, ModalSaveCancel, TEMPLATES.SAVE_CANCEL);
-    // Deprecated since Moodle 3.4. See MDL-59759.
-    ModalRegistry.register(TYPES.CONFIRM, ModalConfirm, TEMPLATES.CONFIRM);
     ModalRegistry.register(TYPES.CANCEL, ModalCancel, TEMPLATES.CANCEL);
 
     /**
