@@ -194,7 +194,7 @@ class behat_navigation extends behat_base {
             // We just want to expand the node, we don't want to follow it.
             $node = $node->getParent();
         }
-        $this->execute('behat_general::i_click_on', [$node, 'NodeElement']);
+        $node->click();
     }
 
     /**
@@ -218,7 +218,7 @@ class behat_navigation extends behat_base {
             // We just want to expand the node, we don't want to follow it.
             $node = $node->getParent();
         }
-        $this->execute('behat_general::i_click_on', [$node, 'NodeElement']);
+        $node->click();
     }
 
     /**
@@ -245,7 +245,7 @@ class behat_navigation extends behat_base {
                 // don't wait, it is non-JS and we already waited for the DOM.
                 $siteadminlink = $this->getSession()->getPage()->find('named_exact', array('link', "'" . $siteadminstr . "'"));
                 if ($siteadminlink) {
-                    $this->execute('behat_general::i_click_on', [$siteadminlink, 'NodeElement']);
+                    $siteadminlink->click();
                 }
             }
         }
@@ -300,9 +300,9 @@ class behat_navigation extends behat_base {
         // Throw exception if no node found.
         if (!$nodetoclick) {
             throw new ExpectationException('Navigation node "' . $nodetext . '" not found under "' .
-                implode($parentnodes, ' > ') . '"', $this->getSession());
+                implode(' > ', $parentnodes) . '"', $this->getSession());
         }
-        $this->execute('behat_general::i_click_on', [$nodetoclick, 'NodeElement']);
+        $nodetoclick->click();
     }
 
     /**
@@ -701,8 +701,6 @@ class behat_navigation extends behat_base {
      * Recognised page names are:
      * | Page type     | Identifier meaning | description                          |
      * | Category page | category idnumber  | List of courses in that category.    |
-     * | Course        | course shortname   | Main course home pag                 |
-     * | Activity      | activity idnumber  | Start page for that activity         |
      *
      * @param string $type identifies which type of page this is, e.g. 'Category page'.
      * @param string $identifier identifies the particular page, e.g. 'test-cat'.
@@ -720,29 +718,13 @@ class behat_navigation extends behat_base {
                 }
                 return new moodle_url('/course/category.php', ['id' => $categoryid]);
 
-            case 'Course':
-                $courseid = $DB->get_field_select('course', 'id', 'shortname = ?', [$identifier], IGNORE_MISSING);
-                if (!$courseid) {
-                    throw new Exception('The specified course with shortname, fullname, or idnumber "' .
-                            $identifier . '" does not exist');
-                }
-                return new moodle_url('/course/view.php', ['id' => $courseid]);
-
-            case 'Activity':
-                $cm = $DB->get_record('course_modules', ['idnumber' => $identifier], 'id, course', IGNORE_MISSING);
-                if (!$cm) {
-                    throw new Exception('The specified activity with idnumber "' . $identifier . '" does not exist');
-                }
-                $modinfo = get_fast_modinfo($cm->course);
-                return $modinfo->cms[$cm->id]->url;
-
             default:
                 throw new Exception('Unrecognised core page type "' . $type . '."');
         }
     }
 
     /**
-     * Opens the course homepage. (Consider using 'I am on the "shortname" "Course" page' step instead.)
+     * Opens the course homepage.
      *
      * @Given /^I am on "(?P<coursefullname_string>(?:[^"]|\\")*)" course homepage$/
      * @throws coding_exception
@@ -791,8 +773,9 @@ class behat_navigation extends behat_base {
         $node = $this->find('xpath', $xpath);
         $expanded = $node->getAttribute('aria-expanded');
         if ($expanded === 'false') {
-            $this->execute('behat_general::i_click_on', [$node, 'NodeElement']);
+            $node->click();
             $this->ensure_node_attribute_is_set($node, 'aria-expanded', 'true');
+            $this->wait_for_pending_js();
         }
     }
 
@@ -811,7 +794,8 @@ class behat_navigation extends behat_base {
         $node = $this->find('xpath', $xpath);
         $expanded = $node->getAttribute('aria-expanded');
         if ($expanded === 'true') {
-            $this->execute('behat_general::i_click_on', [$node, 'NodeElement']);
+            $node->click();
+            $this->wait_for_pending_js();
         }
     }
 
@@ -833,8 +817,8 @@ class behat_navigation extends behat_base {
     protected function go_to_main_course_page() {
         $url = $this->getSession()->getCurrentUrl();
         if (!preg_match('|/course/view.php\?id=[\d]+$|', $url)) {
-            $node = $this->find('xpath', '//header//div[@id=\'page-navbar\']//a[contains(@href,\'/course/view.php?id=\')]');
-            $this->execute('behat_general::i_click_on', [$node, 'NodeElement']);
+            $this->find('xpath', '//header//div[@id=\'page-navbar\']//a[contains(@href,\'/course/view.php?id=\')]')->click();
+            $this->execute('behat_general::wait_until_the_page_is_ready');
         }
     }
 
@@ -854,8 +838,8 @@ class behat_navigation extends behat_base {
             $tabxpath = '//ul[@role=\'tablist\']/li/a[contains(normalize-space(.), ' . $tabname . ')]';
             if ($node = $this->getSession()->getPage()->find('xpath', $tabxpath)) {
                 if ($this->running_javascript()) {
-                    $this->execute('behat_general::i_click_on', [$node, 'NodeElement']);
                     // Click on the tab and add 'active' tab to the xpath.
+                    $node->click();
                     $xpath .= '//div[contains(@class,\'active\')]';
                 } else {
                     // Add the tab content selector to the xpath.
@@ -879,7 +863,8 @@ class behat_navigation extends behat_base {
         if (!$node = $this->getSession()->getPage()->find('xpath', $xpath)) {
             throw new ElementNotFoundException($this->getSession(), 'Link "' . join(' > ', $nodelist) . '"');
         }
-        $this->execute('behat_general::i_click_on', [$node, 'NodeElement']);
+        $node->click();
+        $this->wait_for_pending_js();
     }
 
     /**
@@ -926,8 +911,8 @@ class behat_navigation extends behat_base {
             $menuxpath = $this->find_header_administration_menu() ?: $this->find_page_administration_menu();
         }
         if ($menuxpath && $this->running_javascript()) {
-            $node = $this->find('xpath', $menuxpath . '//a[@data-toggle=\'dropdown\']');
-            $this->execute('behat_general::i_click_on', [$node, 'NodeElement']);
+            $this->find('xpath', $menuxpath . '//a[@data-toggle=\'dropdown\']')->click();
+            $this->wait_for_pending_js();
         }
     }
 
@@ -949,14 +934,15 @@ class behat_navigation extends behat_base {
             $isheader = false;
         }
 
-        $this->execute('behat_navigation::toggle_page_administration_menu', [$menuxpath]);
+        $this->toggle_page_administration_menu($menuxpath);
 
         if (!$isheader || count($nodelist) == 1) {
             $lastnode = end($nodelist);
             $linkname = behat_context_helper::escape($lastnode);
             $link = $this->getSession()->getPage()->find('xpath', $menuxpath . '//a[contains(normalize-space(.), ' . $linkname . ')]');
             if ($link) {
-                $this->execute('behat_general::i_click_on', [$link, 'NodeElement']);
+                $link->click();
+                $this->wait_for_pending_js();
                 return;
             }
         }
@@ -966,7 +952,8 @@ class behat_navigation extends behat_base {
             $linkname = behat_context_helper::escape(get_string('morenavigationlinks'));
             $link = $this->getSession()->getPage()->find('xpath', $menuxpath . '//a[contains(normalize-space(.), ' . $linkname . ')]');
             if ($link) {
-                $this->execute('behat_general::i_click_on', [$link, 'NodeElement']);
+                $link->click();
+                $this->execute('behat_general::wait_until_the_page_is_ready');
                 $this->select_on_administration_page($nodelist);
                 return;
             }
