@@ -26,8 +26,9 @@
 
 defined('MOODLE_INTERNAL') || die();
 
+require_once($CFG->dirroot . '/question/type/questiontypebase.php');
 require_once($CFG->dirroot . '/question/type/multichoice/question.php');
-
+require_once($CFG->dirroot . '/question/type/numerical/questiontype.php');
 
 /**
  * The multi-answer question type class.
@@ -46,14 +47,16 @@ class qtype_multianswer extends question_type {
 
         // Get relevant data indexed by positionkey from the multianswers table.
         $sequence = $DB->get_field('question_multianswer', 'sequence',
-                array('question' => $question->id), '*', MUST_EXIST);
+                array('question' => $question->id), MUST_EXIST);
 
         $wrappedquestions = $DB->get_records_list('question', 'id',
                 explode(',', $sequence), 'id ASC');
 
         // We want an array with question ids as index and the positions as values.
         $sequence = array_flip(explode(',', $sequence));
-        array_walk($sequence, create_function('&$val', '$val++;'));
+        array_walk($sequence, function(&$val) {
+            $val++;
+        });
 
         // If a question is lost, the corresponding index is null
         // so this null convention is used to test $question->options->questions
@@ -89,12 +92,18 @@ class qtype_multianswer extends question_type {
         // will also create difficulties if questiontype specific tables reference the id.
 
         // First we get all the existing wrapped questions.
-        if (!$oldwrappedids = $DB->get_field('question_multianswer', 'sequence',
+        $oldwrappedquestions = [];
+        if ($oldwrappedids = $DB->get_field('question_multianswer', 'sequence',
                 array('question' => $question->id))) {
-            $oldwrappedquestions = array();
-        } else {
-            $oldwrappedquestions = $DB->get_records_list('question', 'id',
-                    explode(',', $oldwrappedids), 'id ASC');
+            $oldwrappedidsarray = explode(',', $oldwrappedids);
+            $unorderedquestions = $DB->get_records_list('question', 'id', $oldwrappedidsarray);
+
+            // Keep the order as given in the sequence field.
+            foreach ($oldwrappedidsarray as $questionid) {
+                if (isset($unorderedquestions[$questionid])) {
+                    $oldwrappedquestions[] = $unorderedquestions[$questionid];
+                }
+            }
         }
 
         $sequence = array();
@@ -279,7 +288,8 @@ define('NUMERICAL_ABS_ERROR_MARGIN', 6);
 define('ANSWER_TYPE_DEF_REGEX',
         '(NUMERICAL|NM)|(MULTICHOICE|MC)|(MULTICHOICE_V|MCV)|(MULTICHOICE_H|MCH)|' .
         '(SHORTANSWER|SA|MW)|(SHORTANSWER_C|SAC|MWC)|' .
-        '(MULTICHOICE_S|MCS)|(MULTICHOICE_VS|MCVS)|(MULTICHOICE_HS|MCHS)');
+        '(MULTICHOICE_S|MCS)|(MULTICHOICE_VS|MCVS)|(MULTICHOICE_HS|MCHS)|'.
+        '(MULTIRESPONSE|MR)|(MULTIRESPONSE_H|MRH)|(MULTIRESPONSE_S|MRS)|(MULTIRESPONSE_HS|MRHS)');
 define('ANSWER_START_REGEX',
        '\{([0-9]*):(' . ANSWER_TYPE_DEF_REGEX . '):');
 
@@ -301,7 +311,11 @@ define('ANSWER_REGEX_ANSWER_TYPE_SHORTANSWER_C', 8);
 define('ANSWER_REGEX_ANSWER_TYPE_MULTICHOICE_SHUFFLED', 9);
 define('ANSWER_REGEX_ANSWER_TYPE_MULTICHOICE_REGULAR_SHUFFLED', 10);
 define('ANSWER_REGEX_ANSWER_TYPE_MULTICHOICE_HORIZONTAL_SHUFFLED', 11);
-define('ANSWER_REGEX_ALTERNATIVES', 12);
+define('ANSWER_REGEX_ANSWER_TYPE_MULTIRESPONSE', 12);
+define('ANSWER_REGEX_ANSWER_TYPE_MULTIRESPONSE_HORIZONTAL', 13);
+define('ANSWER_REGEX_ANSWER_TYPE_MULTIRESPONSE_SHUFFLED', 14);
+define('ANSWER_REGEX_ANSWER_TYPE_MULTIRESPONSE_HORIZONTAL_SHUFFLED', 15);
+define('ANSWER_REGEX_ALTERNATIVES', 16);
 
 /**
  * Initialise subquestion fields that are constant across all MULTICHOICE
@@ -387,6 +401,26 @@ function qtype_multianswer_extract_question($text) {
             qtype_multianswer_initialise_multichoice_subquestion($wrapped);
             $wrapped->shuffleanswers = 1;
             $wrapped->layout = qtype_multichoice_base::LAYOUT_HORIZONTAL;
+        } else if (!empty($answerregs[ANSWER_REGEX_ANSWER_TYPE_MULTIRESPONSE])) {
+            qtype_multianswer_initialise_multichoice_subquestion($wrapped);
+            $wrapped->single = 0;
+            $wrapped->shuffleanswers = 0;
+            $wrapped->layout = qtype_multichoice_base::LAYOUT_VERTICAL;
+        } else if (!empty($answerregs[ANSWER_REGEX_ANSWER_TYPE_MULTIRESPONSE_HORIZONTAL])) {
+            qtype_multianswer_initialise_multichoice_subquestion($wrapped);
+            $wrapped->single = 0;
+            $wrapped->shuffleanswers = 0;
+            $wrapped->layout = qtype_multichoice_base::LAYOUT_HORIZONTAL;
+        } else if (!empty($answerregs[ANSWER_REGEX_ANSWER_TYPE_MULTIRESPONSE_SHUFFLED])) {
+            qtype_multianswer_initialise_multichoice_subquestion($wrapped);
+            $wrapped->single = 0;
+            $wrapped->shuffleanswers = 1;
+            $wrapped->layout = qtype_multichoice_base::LAYOUT_VERTICAL;
+        } else if (!empty($answerregs[ANSWER_REGEX_ANSWER_TYPE_MULTIRESPONSE_HORIZONTAL_SHUFFLED])) {
+            qtype_multianswer_initialise_multichoice_subquestion($wrapped);
+            $wrapped->single = 0;
+            $wrapped->shuffleanswers = 1;
+            $wrapped->layout = qtype_multichoice_base::LAYOUT_HORIZONTAL;
         } else {
             print_error('unknownquestiontype', 'question', '', $answerregs[2]);
             return false;
@@ -403,12 +437,14 @@ function qtype_multianswer_extract_question($text) {
         $wrapped->questiontext['itemid'] = '';
         $answerindex = 0;
 
+        $hasspecificfraction = false;
         $remainingalts = $answerregs[ANSWER_REGEX_ALTERNATIVES];
         while (preg_match('/~?'.ANSWER_ALTERNATIVE_REGEX.'/s', $remainingalts, $altregs)) {
             if ('=' == $altregs[ANSWER_ALTERNATIVE_REGEX_FRACTION]) {
                 $wrapped->fraction["{$answerindex}"] = '1';
             } else if ($percentile = $altregs[ANSWER_ALTERNATIVE_REGEX_PERCENTILE_FRACTION]) {
                 $wrapped->fraction["{$answerindex}"] = .01 * $percentile;
+                $hasspecificfraction = true;
             } else {
                 $wrapped->fraction["{$answerindex}"] = '0';
             }
@@ -453,6 +489,26 @@ function qtype_multianswer_extract_question($text) {
             $answerindex++;
         }
 
+        // Fix the score for multichoice_multi questions (as positive scores should add up to 1, not have a maximum of 1).
+        if (isset($wrapped->single) && $wrapped->single == 0) {
+            $total = 0;
+            foreach ($wrapped->fraction as $idx => $fraction) {
+                if ($fraction > 0) {
+                    $total += $fraction;
+                }
+            }
+            if ($total) {
+                foreach ($wrapped->fraction as $idx => $fraction) {
+                    if ($fraction > 0) {
+                        $wrapped->fraction[$idx] = $fraction / $total;
+                    } else if (!$hasspecificfraction) {
+                        // If no specific fractions are given, set incorrect answers to each cancel out one correct answer.
+                        $wrapped->fraction[$idx] = -(1.0 / $total);
+                    }
+                }
+            }
+        }
+
         $question->defaultmark += $wrapped->defaultmark;
         $question->options->questions[$positionkey] = clone($wrapped);
         $question->questiontext['text'] = implode("{#$positionkey}",
@@ -460,3 +516,65 @@ function qtype_multianswer_extract_question($text) {
     }
     return $question;
 }
+
+/**
+ * Validate a multianswer question.
+ *
+ * @param object $question  The multianswer question to validate as returned by qtype_multianswer_extract_question
+ * @return array Array of error messages with questions field names as keys.
+ */
+function qtype_multianswer_validate_question(stdClass $question) : array {
+    $errors = array();
+    if (!isset($question->options->questions)) {
+        $errors['questiontext'] = get_string('questionsmissing', 'qtype_multianswer');
+    } else {
+        $subquestions = fullclone($question->options->questions);
+        if (count($subquestions)) {
+            $sub = 1;
+            foreach ($subquestions as $subquestion) {
+                $prefix = 'sub_'.$sub.'_';
+                $answercount = 0;
+                $maxgrade = false;
+                $maxfraction = -1;
+
+                foreach ($subquestion->answer as $key => $answer) {
+                    if (is_array($answer)) {
+                        $answer = $answer['text'];
+                    }
+                    $trimmedanswer = trim($answer);
+                    if ($trimmedanswer !== '') {
+                        $answercount++;
+                        if ($subquestion->qtype == 'numerical' &&
+                                !(qtype_numerical::is_valid_number($trimmedanswer) || $trimmedanswer == '*')) {
+                            $errors[$prefix.'answer['.$key.']'] =
+                                    get_string('answermustbenumberorstar', 'qtype_numerical');
+                        }
+                        if ($subquestion->fraction[$key] == 1) {
+                            $maxgrade = true;
+                        }
+                        if ($subquestion->fraction[$key] > $maxfraction) {
+                            $maxfraction = $subquestion->fraction[$key];
+                        }
+                        // For 'multiresponse' we are OK if there is at least one fraction > 0.
+                        if ($subquestion->qtype == 'multichoice' && $subquestion->single == 0 &&
+                            $subquestion->fraction[$key] > 0) {
+                            $maxgrade = true;
+                        }
+                    }
+                }
+                if ($subquestion->qtype == 'multichoice' && $answercount < 2) {
+                    $errors[$prefix.'answer[0]'] = get_string('notenoughanswers', 'qtype_multichoice', 2);
+                } else if ($answercount == 0) {
+                    $errors[$prefix.'answer[0]'] = get_string('notenoughanswers', 'question', 1);
+                }
+                if ($maxgrade == false) {
+                    $errors[$prefix.'fraction[0]'] = get_string('fractionsnomax', 'question');
+                }
+                $sub++;
+            }
+        } else {
+            $errors['questiontext'] = get_string('questionsmissing', 'qtype_multianswer');
+        }
+    }
+    return $errors;
+}
