@@ -26,6 +26,7 @@
 
 defined('MOODLE_INTERNAL') || die();
 
+require_once($CFG->dirroot . '/question/type/questionbase.php');
 
 /**
  * Represents a short answer question.
@@ -56,6 +57,14 @@ class qtype_shortanswer_question extends question_graded_by_strategy
         }
     }
 
+    public function un_summarise_response(string $summary) {
+        if (!empty($summary)) {
+            return ['answer' => $summary];
+        } else {
+            return [];
+        }
+    }
+
     public function is_complete_response(array $response) {
         return array_key_exists('answer', $response) &&
                 ($response['answer'] || $response['answer'] === '0');
@@ -87,15 +96,22 @@ class qtype_shortanswer_question extends question_graded_by_strategy
     }
 
     public static function compare_string_with_wildcard($string, $pattern, $ignorecase) {
-        // Break the string on non-escaped asterisks.
-        $bits = preg_split('/(?<!\\\\)\*/', $pattern);
+
+        // Normalise any non-canonical UTF-8 characters before we start.
+        $pattern = self::safe_normalize($pattern);
+        $string = self::safe_normalize($string);
+
+        // Break the string on non-escaped runs of asterisks.
+        // ** is equivalent to *, but people were doing that, and with many *s it breaks preg.
+        $bits = preg_split('/(?<!\\\\)\*+/', $pattern);
+
         // Escape regexp special characters in the bits.
-        $excapedbits = array();
+        $escapedbits = array();
         foreach ($bits as $bit) {
-            $excapedbits[] = preg_quote(str_replace('\*', '*', $bit));
+            $escapedbits[] = preg_quote(str_replace('\*', '*', $bit), '|');
         }
         // Put it back together to make the regexp.
-        $regexp = '|^' . implode('.*', $excapedbits) . '$|u';
+        $regexp = '|^' . implode('.*', $escapedbits) . '$|u';
 
         // Make the match insensitive if requested to.
         if ($ignorecase) {
@@ -105,6 +121,31 @@ class qtype_shortanswer_question extends question_graded_by_strategy
         return preg_match($regexp, trim($string));
     }
 
+    /**
+     * Normalise a UTf-8 string to FORM_C, avoiding the pitfalls in PHP's
+     * normalizer_normalize function.
+     * @param string $string the input string.
+     * @return string the normalised string.
+     */
+    protected static function safe_normalize($string) {
+        if ($string === '') {
+            return '';
+        }
+
+        if (!function_exists('normalizer_normalize')) {
+            return $string;
+        }
+
+        $normalised = normalizer_normalize($string, Normalizer::FORM_C);
+        if (is_null($normalised)) {
+            // An error occurred in normalizer_normalize, but we have no idea what.
+            debugging('Failed to normalise string: ' . $string, DEBUG_DEVELOPER);
+            return $string; // Return the original string, since it is the best we have.
+        }
+
+        return $normalised;
+    }
+
     public function get_correct_response() {
         $response = parent::get_correct_response();
         if ($response) {
@@ -132,7 +173,7 @@ class qtype_shortanswer_question extends question_graded_by_strategy
         if ($component == 'question' && $filearea == 'answerfeedback') {
             $currentanswer = $qa->get_last_qt_var('answer');
             $answer = $this->get_matching_answer(array('answer' => $currentanswer));
-            $answerid = reset($args); // itemid is answer id.
+            $answerid = reset($args); // Itemid is answer id.
             return $options->feedback && $answer && $answerid == $answer->id;
 
         } else if ($component == 'question' && $filearea == 'hint') {
